==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ast.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "There was a problem reading files from this album" : "Hubo un problema al lleer arquivos d'esti álbum",
    "Aborting preview. Could not find the file" : "Albortando vista previa. Nun s'atopó'l ficheru",
    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
    "Gallery view" : "Vista de galería",
    "Could not load the description" : "Nun pudo cargase la descripción",
    "Could not load the description: " : "Nun pudo cargase la descripción:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nun pudo cargase l'avisu de copyright:",
    "Copyright notice" : "Avisu de copyright ",
    "Link to copyright document" : "Enllaz al documentu de copyright ",
    "This application may not work properly on your browser." : "Esta aplicación puede que nun funcione correchamente nel so restolador.",
    "For an improved experience, please install one of the following alternatives" : "Pa una meyor esperiencia , por favor, instale una de les siguientes alternatives",
    "Your browser is not supported!" : "¡El to restolador nun ye compatible!",
    "please install one of the following alternatives" : "por favor instale una de les siguientes alternatives",
    "Album cannot be shown" : "L'album nun pue amosase",
    "No media files found" : "Nun s'atoparon ficheros multimedia",
    "Upload pictures in the files app to display them here" : "Xubir semeyes nos ficheros d'aplicación p'amosalos equí",
    "Upload new files via drag and drop or by using the [+] button above" : "Xubir nuevos ficheros al traviés d'arrastrar y soltar o utilizando'l botón [+] anterior",
    "Configuration error" : "Error de configuración",
    "New" : "Nuevu",
    "Hide Album" : "Anubrir Álbum",
    "Could not hide album" : "Nun pudo anubrise l'álbum",
    "Error loading slideshow template" : "Fallu al cargar la plantía de diapositives",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>¡Error!</strong>Nun se pudo xenerar una vista previa d'esti ficheru.<br>Por favor, vaya a la siguiente diapositiva mientres esanicia esta imaxe de la presentación de diapositives",
    "Next" : "Siguiente",
    "Play" : "Reproducir",
    "Pause" : "Posar",
    "Previous" : "Anterior",
    "Close" : "Zarrar",
    "Download" : "Baxar",
    "Toggle background" : "Fondu de barra de ferramientes",
    "Delete" : "Desaniciar",
    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Upload" : "Xubir",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "Error while changing permissions" : "Fallu mientres camudaben los permisos",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "Share with users or groups …" : "Compartir con usuarios o grupos",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos o usuarios remotos",
    "Share" : "Compartir",
    "Share link" : "Compartir enllaz",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Link" : "Enllaz",
    "Password protect" : "Protexer con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "An error occured. Please try again" : "Hebo un fallu. Por favor, inténtalo dempués. ",
    "Adding user..." : "Amestando usuariu...",
    "group" : "grupu",
    "remote" : "remotu",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Error while retrieving shares" : "Fallu al recuperar aiciones",
    "Unshare" : "Dexar de compartir",
    "notify by email" : "notificar per corréu",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "access control" : "control d'accesu",
    "create" : "crear",
    "change" : "camudar",
    "delete" : "desaniciar",
    "Password protected" : "Contraseña protexida",
    "Error unsetting expiration date" : "Fallu desafitando la data de caducidá",
    "Error setting expiration date" : "Fallu afitando la fecha de caducidá",
    "Sending ..." : "Unviando ...",
    "Email sent" : "Corréu-e unviáu",
    "Warning" : "Avisu",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Sort by date" : "Ordenar por fecha",
    "Sort by name" : "Ordenador por nome",
    "Cancel upload" : "Encaboxar xuba",
    "Album information" : "Información del album",
    "File list" : "Llista de ficheros",
    "Sorry, this file could not be found." : "Sentímoslo, esti ficheru nun pudo atopase.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the wrong file ID was provided" : "Apurrióse'l ficheru d'ID incorrectu",
    "the file was removed" : "desanicióse'l ficheru",
    "the file is corrupt" : "el ficheru ta toriáu",
    "the encryption key is missing" : "la clave de cifráu nun s'atopa",
    "Here is the error message returned by the server: " : "Equí ta'l mensaxe d'erru devueltu pol servidor:",
    "Sorry, but the server could not fulfill your request." : "Sentímoslo, pero'l servidor nun pudo cumplir cola so solicitú.",
    "Possible reasons for the problem:" : "Les posibles razones pal problema:",
    "a conflicting app was installed" : "Instalóse una aplicación conflictiva",
    "a required component is missing or was disconnected" : "un componente riquíu nun s'atopa o desconectóse",
    "the filesystem is not readable" : "el sistema de ficheros nun ye llexible",
    "For more information, please contact your friendly ownCloud administrator." : "Pa llograr más información, póngase en contactu col alministrador d'ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "the item was removed" : "desanicióse l'elementu",
    "the link has expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more information, please ask the person who has sent you this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz.",
    "Picture view" : "Vista d'imáxenes"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/ast.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galería",
    "There was a problem reading files from this album" : "Hebo un problema al lleer los ficheros d'esti álbum",
    "Aborting preview. Could not find the file" : "Albortando vista previa. Nun s'atopó'l ficheru",
    "Could not move \"{file}\", target exists" : "Nun pudo movese \"{file}\", destín yá esiste",
    "Could not move \"{file}\"" : "Nun pudo movese \"{file}\"",
    "No compatible server found at {remote}" : "Nun s'alcontró dengún sirvidor compatible en {remote}",
    "Gallery view" : "Vista de galería",
    "Could not load the description" : "Nun pudo cargase la descripción",
    "Could not load the description: " : "Nun pudo cargase la descripción:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nun pudo cargase l'avisu de copyright:",
    "Copyright notice" : "Avisu de copyright ",
    "Link to copyright document" : "Enllaz al documentu de copyright ",
    "This application may not work properly on your browser." : "Esta aplicación puede que nun funcione correchamente nel so restolador.",
    "For an improved experience, please install one of the following alternatives" : "Pa una meyor esperiencia , por favor, instale una de les siguientes alternatives",
    "Your browser is not supported!" : "¡El to restolador nun ye compatible!",
    "please install one of the following alternatives" : "por favor instale una de les siguientes alternatives",
    "Album cannot be shown" : "Nun pue amosase l'álbum",
    "No media files found" : "Nun s'atoparon ficheros multimedia",
    "Upload pictures in the files app to display them here" : "Xubir semeyes nos ficheros d'aplicación p'amosalos equí",
    "Upload new files via drag and drop or by using the [+] button above" : "Xubir nuevos ficheros al traviés d'arrastrar y soltar o utilizando'l botón [+] anterior",
    "Configuration error" : "Error de configuración",
    "New" : "Nuevu",
    "Hide Album" : "Anubrir Álbum",
    "Could not hide album" : "Nun pudo anubrise l'álbum",
    "Error loading slideshow template" : "Fallu al cargar la plantía de diapositives",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>¡Error!</strong>Nun se pudo xenerar una vista previa d'esti ficheru.<br>Por favor, vaya a la siguiente diapositiva mientres esanicia esta imaxe de la presentación de diapositives",
    "Next" : "Siguiente",
    "Play" : "Reproducir",
    "Pause" : "Posar",
    "Previous" : "Anterior",
    "Close" : "Zarrar",
    "Download" : "Baxar",
    "Toggle background" : "Fondu de barra de ferramientes",
    "Delete" : "Desaniciar",
    "Could not create file \"{file}\" because it already exists" : "Nun pudo crease'l ficheru \"{file}\" porque yá esiste",
    "Could not create file \"{file}\"" : "Nun pudo crease'l ficheru \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" ye un nome de ficheru inválidu.",
    "File name cannot be empty." : "El nome de ficheru nun pue quedar baleru.",
    "Upload" : "Xubir",
    "Error" : "Fallu",
    "Error while sharing" : "Fallu mientres la compartición",
    "Error while unsharing" : "Fallu mientres se dexaba de compartir",
    "Error while changing permissions" : "Fallu mientres camudaben los permisos",
    "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
    "Shared with you by {owner}" : "Compartíu contigo por {owner}",
    "Share with users or groups …" : "Compartir con usuarios o grupos",
    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos o usuarios remotos",
    "Share" : "Compartir",
    "Share link" : "Compartir enllaz",
    "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
    "Link" : "Enllaz",
    "Password protect" : "Protexer con contraseña",
    "Password" : "Contraseña",
    "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enllaz de corréu-e a la persona",
    "Send" : "Unviar",
    "Set expiration date" : "Afitar la data de caducidá",
    "Expiration" : "Caducidá",
    "Expiration date" : "Data de caducidá",
    "An error occured. Please try again" : "Hebo un fallu. Por favor, inténtalo dempués. ",
    "Adding user..." : "Amestando usuariu...",
    "group" : "grupu",
    "remote" : "remotu",
    "Resharing is not allowed" : "Recompartir nun ta permitíu",
    "Error while retrieving shares" : "Fallu al recuperar aiciones",
    "Unshare" : "Dexar de compartir",
    "notify by email" : "notificar per corréu",
    "can share" : "pue compartir",
    "can edit" : "pue editar",
    "access control" : "control d'accesu",
    "create" : "crear",
    "change" : "camudar",
    "delete" : "desaniciar",
    "Password protected" : "Contraseña protexida",
    "Error unsetting expiration date" : "Fallu desafitando la data de caducidá",
    "Error setting expiration date" : "Fallu afitando la fecha de caducidá",
    "Sending ..." : "Unviando ...",
    "Warning" : "Avisu",
    "This share is password-protected" : "Esta compartición tien contraseña protexida",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "Sort by date" : "Ordenar por fecha",
    "Sort by name" : "Ordenador por nome",
    "Cancel upload" : "Encaboxar xuba",
    "Album information" : "Información del album",
    "File list" : "Llista de ficheros",
    "Sorry, this file could not be found." : "Sentímoslo, esti ficheru nun pudo atopase.",
    "Reasons might be:" : "Les razones pueden ser: ",
    "the wrong file ID was provided" : "Apurrióse'l ficheru d'ID incorrectu",
    "the file was removed" : "desanicióse'l ficheru",
    "the file is corrupt" : "el ficheru ta toriáu",
    "the encryption key is missing" : "la clave de cifráu nun s'atopa",
    "Here is the error message returned by the server: " : "Equí ta'l mensaxe d'erru devueltu pol servidor:",
    "Sorry, but the server could not fulfill your request." : "Sentímoslo, pero'l servidor nun pudo cumplir cola so solicitú.",
    "Possible reasons for the problem:" : "Les posibles razones pal problema:",
    "a conflicting app was installed" : "Instalóse una aplicación conflictiva",
    "a required component is missing or was disconnected" : "un componente riquíu nun s'atopa o desconectóse",
    "the filesystem is not readable" : "el sistema de ficheros nun ye llexible",
    "For more information, please contact your friendly ownCloud administrator." : "Pa llograr más información, póngase en contactu col alministrador d'ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Sentímoslo, esti enllaz paez que yá nun furrula.",
    "the item was removed" : "desanicióse l'elementu",
    "the link has expired" : "l'enllaz caducó",
    "sharing is disabled" : "la compartición ta deshabilitada",
    "For more information, please ask the person who has sent you this link." : "Pa más información, entrúga-y a la persona qu'unvió esti enllaz.",
    "Picture view" : "Vista d'imáxenes"
},
"nplurals=2; plural=(n != 1);");
